@@ -60,7 +60,7 @@ mgQuick <- function(genD, coords, longlat = FALSE, truncation = NULL, transforma
       ))
     }
     )
-    if (class(selectedPos) == "list") {
+    if (inherits(selectedPos, "list")) {
       return(selectedPos)
     }
     if (verbose) cat("----Selected:", ifelse(length(selectedPos) == 0, "None", paste(sort(selectedPos), collapse = ", ")), "\n")
@@ -87,7 +87,7 @@ mgQuick <- function(genD, coords, longlat = FALSE, truncation = NULL, transforma
       ))
     }
     )
-    if (class(selectedNeg) == "list") {
+    if (inherits(selectedNeg, "list")) {
       return(selectedNeg)
     }
     if (verbose) cat("----Selected:", ifelse(length(selectedNeg) == 0, "None", paste(sort(selectedNeg), collapse = ", ")), "\n")
